@@ -69,6 +69,8 @@ static void usage()
 		 "\tlock: The new process is trapped and can't use chcontext anymore.\n"
 		 "\tsched: The new process and its children will share a common \n"
 		 "         execution priority.\n"
+		 "\tmount: Hide /proc/mounts content\n"
+		 "\tnetif: Hide network devices not owned by this context\n"
 		 "\tnproc: Limit the number of process in the vserver according to\n"
 		 "         ulimit setting. Normally, ulimit is a per user thing.\n"
 		 "         With this flag, it becomes a per vserver thing.\n"
@@ -149,6 +151,10 @@ int main (int argc, char *argv[])
 				flags |= 32;
 			}else if (strcmp(opt,"ulimit")==0){
 				flags |= 64;
+			}else if (strcmp(opt,"mount")==0){
+				flags |= 0x01000000;
+			}else if (strcmp(opt,"netif")==0){
+				flags |= 0x02000000;
 			}else{
 				fprintf (stderr,"Unknown flag %s\n",opt);
 			}
