@@ -1,17 +1,18 @@
 #!/bin/sh
 
+ETC_VSERVERS=/etc/vservers
 vserver_mknod()
 {
 	mknod $1 $2 $3 $4
 	chmod $5 $1
 }
 
-if [ $# != 1 ] ; then
-	echo install-pre.sh vserver
+if [ $# != 2 ] ; then
+	echo install-pre.sh vserver vroot
 else
-	mkdir -p /etc/vservers
-	mkdir -p /vservers 2>/dev/null
-	VROOT=/vservers/$1
+	VROOT=$2
+	mkdir -p $ETC_VSERVERS
+	mkdir -p $VROOT 2>/dev/null
 	rm -fr $VROOT/dev
 	mkdir -p $VROOT/dev && chmod 755 $VROOT/dev
 	mkdir $VROOT/dev/pts
