@@ -58,6 +58,10 @@ else
 	if [ "$VSERVERDIR" = "" ] ;then
 		VSERVERDIR=$VSERVERS_ROOT/$1
 	fi
+	printvar OWNER $OWNER
+	printvar BUILDFROM $BUILDFROM
+	printvar BUILDUSING $BUILDUSING
+	printvar BUILDARGS $BUILDARGS
 	printvar VSERVERS_ROOT $VSERVERS_ROOT
 	printvar VSERVERDIR $VSERVERDIR
 	printvar PROFILE $PROFILE
@@ -73,6 +77,7 @@ else
 	printvar S_NICE $S_NICE
 	printvar S_FLAGS $S_FLAGS
 	printvar ULIMIT $ULIMIT
+	printvar REQ_S_CONTEXT $S_CONTEXT
 	exit 0
 fi
 
