@@ -33,7 +33,7 @@
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <sys/un.h>
-
+#include "vutil.h"
 
 static void usage()
 {
@@ -45,29 +45,32 @@ static void usage()
 static int rebootmgr_opensocket (const char *vname)
 {
 	int ret = -1;
-	char sockn[PATH_MAX];
-	sprintf (sockn,"/vservers/%s/dev/reboot",vname);
-	unlink (sockn);
-	int fd =  socket (AF_UNIX,SOCK_STREAM,0);
-	if (fd == -1){
-		fprintf (stderr,"Can't create a unix domain socket (%s)\n"
-				,strerror(errno));
-	}else{
-		struct sockaddr_un un;
-		un.sun_family = AF_UNIX;
-		strcpy (un.sun_path,sockn);
-		if (bind(fd,(struct sockaddr*)&un,sizeof(un))==-1){
-			fprintf (stderr,"Can't bind to file %s (%s)\n",sockn
-				,strerror(errno));
+	VSERVER_CONF conf;
+	if (vutil_readconf (vname,conf) != -1){
+		char sockn[PATH_MAX];
+		sprintf (sockn,"%s/dev/reboot",conf.vserverdir.c_str());
+		unlink (sockn);
+		int fd =  socket (AF_UNIX,SOCK_STREAM,0);
+		if (fd == -1){
+			fprintf (stderr,"Can't create a unix domain socket (%s)\n"
+					,strerror(errno));
 		}else{
-			chmod (sockn,0600);
-			int code = ::listen (fd,10);
-			if (code == -1){
-				fprintf (stderr,"Can't listen to file %s (%s)\n",sockn
+			struct sockaddr_un un;
+			un.sun_family = AF_UNIX;
+			strcpy (un.sun_path,sockn);
+			if (bind(fd,(struct sockaddr*)&un,sizeof(un))==-1){
+				fprintf (stderr,"Can't bind to file %s (%s)\n",sockn
 					,strerror(errno));
 			}else{
-				ret = fd;
-			}	
+				chmod (sockn,0600);
+				int code = ::listen (fd,10);
+				if (code == -1){
+					fprintf (stderr,"Can't listen to file %s (%s)\n",sockn
+						,strerror(errno));
+				}else{
+					ret = fd;
+				}	
+			}
 		}
 	}
 	return ret;
@@ -172,7 +175,7 @@ int main (int argc, char *argv[])
 						int fd = sockets[i];
 						if (FD_ISSET(fd,&fdin)){
 							struct sockaddr_un unc;
-							size_t len = sizeof(unc);
+							socklen_t len = sizeof(unc);
 							unc.sun_family = AF_UNIX;
 							fd = accept (fd,(struct sockaddr*)&unc,&len);
 							if (fd != -1){
