@@ -1,6 +1,11 @@
 #include "linux/vswitch.h"
 #include <errno.h>
 #include <asm/unistd.h>
+#define _UNISTD_H
+#ifndef PROTO_SKIP
+extern "C" long int syscall (long int __sysno, ...) __THROW;
+#endif
+#include <linux/unistd.h>
 #include "old_syscall.p"
 #include <stdio.h>
 
