@@ -23,7 +23,8 @@ using namespace std;
 
 static bool undo = false;
 
-static int  ext2flags = EXT2_IMMUTABLE_FILE_FL | EXT2_IMMUTABLE_LINK_FL;
+static int  ext2flags = EXT2_IMMUTABLE_FILE_FL | vutil_get_iunlinkflag();
+
 struct EXCLDIR{
 	string prefix;
 	int len;
@@ -98,14 +99,14 @@ public:
 		: PACKAGE (line)
 	{
 	}
-	// Load the file member of the package, but exclude configuration file
-	void loadfiles(const string &ref)
+	// Load the file members of the package, but exclude configuration file
+	void loadfiles(const string &root_ref)
 	{
 		if (files.empty()){
 			if (debug) cout << "Loading files for package " << name << endl;
 			string namever;
 			namever = name + '-' + version;
-			FILE *fin = vutil_execdistcmd (K_UNIFILES,ref,namever.c_str());
+			FILE *fin = vutil_execdistcmd (K_UNIFILES,root_ref,namever.c_str());
 			if (fin != NULL){
 				char tmp[1000];
 				while (fgets(tmp,sizeof(tmp)-1,fin)!=NULL){
@@ -176,19 +177,19 @@ static void vunify_loadallpkg (string &refserver, list<PACKAGE_UNI> &packages)
 	the immutable flag is done
 */
 class file_unifier{
-	string &ref_server,&target_server;
+	string &root_ref_server,&root_target_server;
 	int &ret;
 	public:
 	file_unifier(string &_ref, string &_target, int &_ret)
-		: ref_server(_ref),target_server(_target), ret(_ret)
+		: root_ref_server(_ref),root_target_server(_target), ret(_ret)
 	{}
 	void operator()(const string &file)
 	{
-		string refpath = "/vservers/" + ref_server + file;
-		string dstpath = "/vservers/" + target_server + file;
+		string refpath = root_ref_server + file;
+		string dstpath = root_target_server + file;
 		if (debug) cout << "Unify " << refpath << " -> " << dstpath << endl;
-		struct stat st;
-		if (stat(refpath.c_str(),&st)==-1){
+		struct stat64 st;
+		if (stat64(refpath.c_str(),&st)==-1){
 			if (debug) cout << "File " << refpath << " does not exist, ignored\n";
 		}else if (setext2flag(refpath.c_str(),false,ext2flags)==-1){
 			ret = -1;
@@ -233,14 +234,14 @@ public:
 // Predicate to decide if a package must be unified
 class package_unifier{
 public:
-	string &ref_server,&target_server;
+	string &root_ref_server,&root_target_server;
 	list<PACKAGE_UNI> &target_packages;
 	int &ret;
 	package_unifier(string &_ref,
 			string &_target,
 			list<PACKAGE_UNI> &_target_packages,
 			int &_ret)
-		: ref_server(_ref),target_server(_target)
+		: root_ref_server(_ref),root_target_server(_target)
 		, target_packages(_target_packages) , ret(_ret)
 	{}
 	void operator()(PACKAGE_UNI &pkg)
@@ -248,21 +249,21 @@ public:
 		if (find(target_packages.begin(),target_packages.end(),pkg)
 			!=target_packages.end()){
 			// Ok, the package is also in the target vserver
-			cout << "Unify pkg " << pkg << " from " << ref_server << " to "
-				<< target_server << endl;
+			cout << "Unify pkg " << pkg << " from " << root_ref_server << " to "
+				<< root_target_server << endl;
 
 			if (!testmode || debug){
-				pkg.loadfiles(ref_server);
+				pkg.loadfiles(root_ref_server);
 				for_each (pkg.files.begin(),pkg.files.end()
-					,file_unifier(ref_server,target_server,ret));
+					,file_unifier(root_ref_server,root_target_server,ret));
 			}
 		}else if (testmode){
 			// The package is missing, in test mode we provide more information
 			if (find_if(target_packages.begin(),target_packages.end(),same_name(pkg))
 				!=target_packages.end()){
-				cout << pkg << " exist in server " << target_server << " not unified\n";
+				cout << pkg << " exist in server " << root_target_server << " not unified\n";
 			}else{
-				cout << pkg << " does not exist in server " << target_server << endl;
+				cout << pkg << " does not exist in server " << root_target_server << endl;
 			}
 		}
 	}
@@ -272,17 +273,22 @@ public:
 class server_unifier{
 public:
 	list<PACKAGE_UNI> &ref_packages;
-	string &ref_server;
+	string &root_ref_server;
 	int &ret;
 	server_unifier(string _ref_server, list<PACKAGE_UNI> &_packages, int &_ret)
-		: ref_packages(_packages),ref_server(_ref_server), ret(_ret)
+		: ref_packages(_packages),root_ref_server(_ref_server), ret(_ret)
 		{}
 	void operator()(string serv)
 	{
 		list<PACKAGE_UNI> pkgs;
-		vunify_loadallpkg (serv,pkgs);
-		for_each(ref_packages.begin(),ref_packages.end()
-			,package_unifier(ref_server,serv,pkgs,ret));
+		VSERVER_CONF conf;
+		if (vutil_readconf (serv,conf)!=-1){
+			vunify_loadallpkg (serv,pkgs);
+			for_each(ref_packages.begin(),ref_packages.end()
+				,package_unifier(root_ref_server,conf.vserverdir,pkgs,ret));
+		}else{
+			ret = -1;
+		}
 	}
 };
 class deleteif{
@@ -320,7 +326,7 @@ int main (int argc, char *argv[])
 		}else if (strcmp(arg,"--immutable")==0){
 			ext2flags |= EXT2_IMMUTABLE_FILE_FL;
 		}else if (strcmp(arg,"--immutable-mayunlink")==0){
-			ext2flags |= EXT2_IMMUTABLE_LINK_FL;
+			ext2flags |= vutil_get_iunlinkflag();
 		}else if (strcmp(arg,"--excldir")==0){
 			i++;
 			//excldirs[excldirs.size()] = EXCLDIR(argv[i]);
@@ -347,14 +353,18 @@ int main (int argc, char *argv[])
 			i++;
 			if (i < argc){
 				list<PACKAGE_UNI> packages;
-				vunify_loadallpkg (refserv,packages);
-				if (i != argc-1 || strcmp(argv[i],"ALL")!=0){
-					// We keep only the packages supplied on the command line
-					packages.remove_if(deleteif (argv+i,argv+argc));
+				VSERVER_CONF refconf;
+				if (vutil_readconf (refserv,refconf) != -1){
+					vunify_loadallpkg (refserv,packages);
+					if (i != argc-1 || strcmp(argv[i],"ALL")!=0){
+						// We keep only the packages supplied on the command line
+						packages.remove_if(deleteif (argv+i,argv+argc));
+					}
+					ret = 0;
+					umask (0);
+					for_each (vservers.begin(),vservers.end()
+						,server_unifier(refconf.vserverdir,packages,ret));
 				}
-				ret = 0;
-				umask (0);
-				for_each (vservers.begin(),vservers.end(),server_unifier(refserv,packages,ret));
 			}else{
 				usage();
 			}
