@@ -4,6 +4,7 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
+#include <sys/utsname.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <utime.h>
@@ -14,7 +15,7 @@
 bool testmode;
 int debug;
 
-int file_copy (const char *src, const char *dst, struct stat &st)
+int file_copy (const char *src, const char *dst, struct stat64 &st)
 {
 	int ret = -1;
 	FILE *fin = fopen (src,"r");
@@ -73,7 +74,7 @@ int setext2flag (const char *fname, bool set, int ext2flags)
 			ret = ioctl (fd,EXT2_IOC_SETFLAGS,&flags);
 			close (fd);
 			if (ret == -1){
-				fprintf (stderr,"Can't %s immutable flag on file %s (^s)\n"
+				fprintf (stderr,"Can't %s immutable flag on file %s (%s)\n"
 					,(set ? "set" : "unset")
 					,fname
 					,strerror(errno));
@@ -92,8 +93,8 @@ int vbuild_mkdir (const char *path, mode_t mode)
 	}else{
 		ret = mkdir (path,mode);
 		if (ret == -1 && errno == EEXIST){
-			struct stat st;
-			if (lstat(path,&st)!=-1	&& S_ISDIR(st.st_mode)){
+			struct stat64 st;
+			if (lstat64(path,&st)!=-1	&& S_ISDIR(st.st_mode)){
 				ret = chmod (path,mode);
 			}
 		}
@@ -110,9 +111,9 @@ int vbuild_mknod(const char *path, mode_t mode, dev_t dev)
 	}else{
 		ret = mknod (path,mode,dev);
 		if (ret == -1 && errno == EEXIST){
-			struct stat st;
-			lstat(path,&st);
-			if (lstat(path,&st)!=-1
+			struct stat64 st;
+			//lstat64(path,&st);
+			if (lstat64(path,&st)!=-1
 				&& (st.st_mode & S_IFMT) == (mode & S_IFMT)
 				&& st.st_rdev == dev){
 				ret = chmod (path,mode);
@@ -172,7 +173,7 @@ int vbuild_chown(const char *path, uid_t uid, gid_t gid)
 int vbuild_file_copy(
 	const char *src,
 	const char *dst,
-	struct stat &st)
+	struct stat64 &st)
 {
 	int ret = -1;
 	if (testmode){
@@ -201,10 +202,10 @@ void vutil_loadallpkg (string &refserver, list<PACKAGE> &packages)
 	}
 }
 
-int vutil_lstat (string path, struct stat &st)
+int vutil_lstat (string path, struct stat64 &st)
 {
 	int ret = 0;
-	if (lstat(path.c_str(),&st) == -1){
+	if (lstat64(path.c_str(),&st) == -1){
 		fprintf (stderr,"Can't lstat file %s (%s)\n"
 			,path.c_str(),strerror(errno));
 		ret = -1;
@@ -288,3 +289,39 @@ int vutil_readconf (const string &name, VSERVER_CONF &conf)
 	return vutil_readconf (name.c_str(),conf);
 }
 
+/*
+	Return the extended attribute flag for IUNLINK.
+	(It changed between 2.4 and 2.6)
+*/
+unsigned vutil_get_iunlinkflag()
+{
+	unsigned ret = EXT2_IMMUTABLE_LINK_FL;
+	struct utsname uts;
+	if (uname(&uts)!=-1){
+		//printf ("sysname :%s:\n",uts.sysname);
+		//printf ("release :%s:\n",uts.release);
+		if (strcmp(uts.release,"2.6.")< 0){
+			ret = EXT2_IMMUTABLE_LINK_FL24;
+		}
+	}
+	return ret;
+}
+
+/*
+	Return the extended attribute flag for IBARRIER.
+	(It changed between 2.4 and 2.6)
+*/
+unsigned vutil_get_ibarrierflag()
+{
+	unsigned ret = EXT2_IBARRIER_FL;
+	struct utsname uts;
+	if (uname(&uts)!=-1){
+		//printf ("sysname :%s:\n",uts.sysname);
+		//printf ("release :%s:\n",uts.release);
+		if (strcmp(uts.release,"2.6.")< 0){
+			ret = EXT2_IBARRIER_FL24;
+		}
+	}
+	return ret;
+}
+
