@@ -18,8 +18,11 @@ extern bool testmode;
 
 // Patch to help compile this utility on unpatched kernel source
 #ifndef EXT2_IMMUTABLE_FILE_FL
-	#define EXT2_IMMUTABLE_FILE_FL	0x00000010
-	#define EXT2_IMMUTABLE_LINK_FL	0x00008000
+	#define EXT2_IMMUTABLE_FILE_FL		0x00000010
+	#define EXT2_IMMUTABLE_LINK_FL24	0x00008000
+	#define EXT2_IMMUTABLE_LINK_FL		0x08000000
+	#define EXT2_IBARRIER_FL24			0x04000000
+	#define EXT2_IBARRIER_FL				0x04000000
 #endif
 
 
@@ -86,6 +89,7 @@ public:
 				if (last >= 0 && tmp[last] == '\n') tmp[last] = '\0';
 				files.insert (tmp);
 			}
+			pclose (fin);
 		}
 		if (debug > 2) cout << "Done\n";
 	}
@@ -109,6 +113,22 @@ public:
 };
 
 
+struct VSERVER_CONF{
+	string vserversroot;
+	string vserverdir;
+	string iproot;
+	string iprootdev;
+	string iprootmask;
+	bool onboot;
+	string s_flags;
+	string s_hostname;
+	string s_domainname;
+	string s_caps;
+	int priority;
+	int s_nice;
+};
+
+
 #include "vutil.p"
 
 #endif
